All of lore.kernel.org
 help / color / mirror / Atom feed
From: Hans Verkuil <hverkuil-cisco@xs4all.nl>
To: linux-media@vger.kernel.org
Cc: Hans Verkuil <hverkuil-cisco@xs4all.nl>,
	Irui Wang <irui.wang@mediatek.com>,
	Andrew-CT Chen <andrew-ct.chen@mediatek.com>
Subject: [PATCH 13/13] mtk-vpu/mtk_vpu.h: fix kernel-doc warnings
Date: Thu, 11 Mar 2021 11:20:22 +0100	[thread overview]
Message-ID: <20210311102022.96954-14-hverkuil-cisco@xs4all.nl> (raw)
In-Reply-To: <20210311102022.96954-1-hverkuil-cisco@xs4all.nl>

A top-level documentation block was missing 'DOC:'.

Fix typos in vpu_wdt_reg_handler() and vpu_mapping_dm_addr().

Signed-off-by: Hans Verkuil <hverkuil-cisco@xs4all.nl>
Cc: Irui Wang <irui.wang@mediatek.com>
Cc: Andrew-CT Chen <andrew-ct.chen@mediatek.com>
---
 drivers/media/platform/mtk-vpu/mtk_vpu.h | 18 ++++++++++--------
 1 file changed, 10 insertions(+), 8 deletions(-)

diff --git a/drivers/media/platform/mtk-vpu/mtk_vpu.h b/drivers/media/platform/mtk-vpu/mtk_vpu.h
index ee7c552ce928..a56053ff135a 100644
--- a/drivers/media/platform/mtk-vpu/mtk_vpu.h
+++ b/drivers/media/platform/mtk-vpu/mtk_vpu.h
@@ -10,10 +10,12 @@
 #include <linux/platform_device.h>
 
 /**
+ * DOC: VPU
+ *
  * VPU (video processor unit) is a tiny processor controlling video hardware
  * related to video codec, scaling and color format converting.
  * VPU interfaces with other blocks by share memory and interrupt.
- **/
+ */
 
 typedef void (*ipi_handler_t) (const void *data,
 			       unsigned int len,
@@ -126,18 +128,18 @@ struct platform_device *vpu_get_plat_device(struct platform_device *pdev);
  * vpu_wdt_reg_handler - register a VPU watchdog handler
  *
  * @pdev:               VPU platform device
  * @vpu_wdt_reset_func:	the callback reset function
  * @private_data:       the private data for reset function
  * @rst_id:		reset id
  *
  * Register a handler performing own tasks when vpu reset by watchdog
  *
  * Return: Return 0 if the handler is added successfully,
  * otherwise it is failed.
- *
  **/
 int vpu_wdt_reg_handler(struct platform_device *pdev,
-			void vpu_wdt_reset_func(void *),
+			void vpu_wdt_reset_func(void *priv),
 			void *priv, enum rst_id id);
 
 /**
@@ -171,8 +173,8 @@ int vpu_load_firmware(struct platform_device *pdev);
 /**
  * vpu_mapping_dm_addr - Mapping DTCM/DMEM to kernel virtual address
  *
- * @pdev:	VPU platform device
- * @dmem_addr:	VPU's data memory address
+ * @pdev:		VPU platform device
+ * @dtcm_dmem_addr:	VPU's data memory address
  *
  * Mapping the VPU's DTCM (Data Tightly-Coupled Memory) /
  * DMEM (Data Extended Memory) memory address to
@@ -126,18 +128,18 @@ struct platform_device *vpu_get_plat_device(struct platform_device *pdev);
  *
  * @pdev:               VPU platform device
- * @vpu_wdt_reset_func:	the callback reset function
- * @private_data:       the private data for reset function
- * @rst_id:		reset id
+ * @vpu_wdt_reset_func():	the callback reset function
+ *	@priv: the private data for reset function
+ * @priv:		the private data for reset function
+ * @id:			reset id
  *
  * Register a handler performing own tasks when vpu reset by watchdog
-- 
2.30.1


      parent reply	other threads:[~2021-03-11 10:21 UTC|newest]

Thread overview: 19+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2021-03-11 10:20 [PATCH 00/13] media platform: fix kernel-doc formatting Hans Verkuil
2021-03-11 10:20 ` [PATCH 01/13] exynos-gsc/exynos4-is: add missing 'struct' to kerneldoc Hans Verkuil
2021-03-11 10:20 ` [PATCH 02/13] s5p-jpeg: fix kernel-doc warnings Hans Verkuil
2021-03-11 10:20 ` [PATCH 03/13] ti-vpe/cal.h: fix kernel-doc formatting Hans Verkuil
2021-03-16 15:03   ` Tomi Valkeinen
2021-03-11 10:20 ` [PATCH 04/13] rcar-vin/rcar-vin.h: " Hans Verkuil
2021-03-11 12:12   ` Niklas Söderlund
2021-03-11 10:20 ` [PATCH 05/13] media/platform/sti: " Hans Verkuil
2021-03-11 10:20 ` [PATCH 06/13] vsp1/vsp1_drm.h: add missing 'struct' kernel-doc keyword Hans Verkuil
2021-03-11 12:12   ` Laurent Pinchart
2021-03-11 12:35     ` Hans Verkuil
2021-03-11 10:20 ` [PATCH 07/13] staging: media: hantro: fix kernel-doc formatting Hans Verkuil
2021-03-11 14:19   ` Ezequiel Garcia
2021-03-11 10:20 ` [PATCH 08/13] staging: media: ipu3: add missing kernel-doc 'struct' keywords Hans Verkuil
2021-03-11 10:20 ` [PATCH 09/13] staging: media: meson: vdec: fix kernel-doc warning Hans Verkuil
2021-03-11 10:20 ` [PATCH 10/13] mtk-jpeg/mtk_jpeg_core.h: fix kernel-doc warnings Hans Verkuil
2021-03-11 10:20 ` [PATCH 11/13] mtk-mdp: " Hans Verkuil
2021-03-11 10:20 ` [PATCH 12/13] mtk-vcodec: " Hans Verkuil
2021-03-11 10:20 ` Hans Verkuil [this message]

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20210311102022.96954-14-hverkuil-cisco@xs4all.nl \
    --to=hverkuil-cisco@xs4all.nl \
    --cc=andrew-ct.chen@mediatek.com \
    --cc=irui.wang@mediatek.com \
    --cc=linux-media@vger.kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.